diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index f9692a38cb1702a61ab6599b8c62640fa41a62c8..087a691a8a4738f9c9a90b9a2dff05b3fb23cd4b 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -182,7 +182,7 @@ dbunittests_mysql:
     - yum -y install lsof mariadb-server
     - echo '[mariadb]' > /etc/my.cnf.d/cta_server_listen.cnf
     - echo 'bind-address=localhost' >> /etc/my.cnf.d/cta_server_listen.cnf
-    - mysql_install_db --user=mysql
+    - mysql_install_db --basedir=/usr --user=mysql
     - /usr/bin/mysqld_safe > /dev/null 2>&1 < /dev/null &
     - sleep 5
     - echo 'create database cta;' | mysql
diff --git a/catalogue/Catalogue.hpp b/catalogue/Catalogue.hpp
index 8c781cab51e1a59ae95a8bf16f32223f97f686ac..bbbfca2fd08dfa6af4927d1c2c4fee2b7da0310a 100644
--- a/catalogue/Catalogue.hpp
+++ b/catalogue/Catalogue.hpp
@@ -380,7 +380,7 @@ public:
   virtual void modifyTapeLogicalLibraryName(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &logicalLibraryName) = 0;
   virtual void modifyTapeTapePoolName(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &tapePoolName) = 0;
   virtual void modifyTapeCapacityInBytes(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const uint64_t capacityInBytes) = 0;
-  virtual void modifyTapeEncryptionKey(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &encryptionKey) = 0;
+  virtual void modifyTapeEncryptionKeyName(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &encryptionKeyName) = 0;
 
   /**
    * Sets the full status of the specified tape.
diff --git a/catalogue/CatalogueRetryWrapper.hpp b/catalogue/CatalogueRetryWrapper.hpp
index 3231bb28fa11a77422a9c0cbf068b995b0f5c493..725718a1790b244f47b5faf67a4acacb7d0e47a0 100644
--- a/catalogue/CatalogueRetryWrapper.hpp
+++ b/catalogue/CatalogueRetryWrapper.hpp
@@ -265,8 +265,8 @@ public:
     return retryOnLostConnection(m_log, [&]{return m_catalogue->modifyTapeCapacityInBytes(admin, vid, capacityInBytes);}, m_maxTriesToConnect);
   }
 
-  void modifyTapeEncryptionKey(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &encryptionKey) override {
-    return retryOnLostConnection(m_log, [&]{return m_catalogue->modifyTapeEncryptionKey(admin, vid, encryptionKey);}, m_maxTriesToConnect);
+  void modifyTapeEncryptionKeyName(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &encryptionKeyName) override {
+    return retryOnLostConnection(m_log, [&]{return m_catalogue->modifyTapeEncryptionKeyName(admin, vid, encryptionKeyName);}, m_maxTriesToConnect);
   }
 
   void setTapeFull(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const bool fullValue) override {
diff --git a/catalogue/CatalogueTest.cpp b/catalogue/CatalogueTest.cpp
index ae8120016177646ed65695cba907be43e5e36ef2..fb3af14b415e3ebc278f65e727fc26959f500b56 100644
--- a/catalogue/CatalogueTest.cpp
+++ b/catalogue/CatalogueTest.cpp
@@ -4410,7 +4410,7 @@ TEST_P(cta_catalogue_CatalogueTest, modifyTapeCapacityInBytes_nonExistentTape) {
   ASSERT_THROW(m_catalogue->modifyTapeCapacityInBytes(m_admin, vid, capacityInBytes), exception::UserError);
 }
 
-TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKey) {
+TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKeyName) {
   using namespace cta;
 
   ASSERT_TRUE(m_catalogue->getTapes().empty());
@@ -4468,8 +4468,8 @@ TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKey) {
     ASSERT_EQ(creationLog, lastModificationLog);
   }
 
-  const std::string modifiedEncryptionKey = "modified_encryption_key";
-  m_catalogue->modifyTapeEncryptionKey(m_admin, vid, modifiedEncryptionKey);
+  const std::string modifiedEncryptionKeyName = "modified_encryption_key_name";
+  m_catalogue->modifyTapeEncryptionKeyName(m_admin, vid, modifiedEncryptionKeyName);
 
   {
     const std::list<common::dataStructures::Tape> tapes = m_catalogue->getTapes();
@@ -4483,7 +4483,7 @@ TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKey) {
     ASSERT_EQ(logicalLibraryName, tape.logicalLibraryName);
     ASSERT_EQ(tapePoolName, tape.tapePoolName);
     ASSERT_EQ(vo, tape.vo);
-    ASSERT_EQ(modifiedEncryptionKey, tape.encryptionKey);
+    ASSERT_EQ(modifiedEncryptionKeyName, tape.encryptionKeyName);
     ASSERT_EQ(capacityInBytes, tape.capacityInBytes);
     ASSERT_TRUE(disabledValue == tape.disabled);
     ASSERT_TRUE(fullValue == tape.full);
@@ -4500,7 +4500,7 @@ TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKey) {
   }
 }
 
-TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKey_emptyStringEncryptionKey) {
+TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKeyName_emptyStringEncryptionKey) {
   using namespace cta;
 
   ASSERT_TRUE(m_catalogue->getTapes().empty());
@@ -4558,8 +4558,8 @@ TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKey_emptyStringEncryptio
     ASSERT_EQ(creationLog, lastModificationLog);
   }
 
-  const std::string modifiedEncryptionKey;
-  m_catalogue->modifyTapeEncryptionKey(m_admin, vid, modifiedEncryptionKey);
+  const std::string modifiedEncryptionKeyName;
+  m_catalogue->modifyTapeEncryptionKeyName(m_admin, vid, modifiedEncryptionKeyName);
 
   {
     const std::list<common::dataStructures::Tape> tapes = m_catalogue->getTapes();
@@ -4573,7 +4573,7 @@ TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKey_emptyStringEncryptio
     ASSERT_EQ(logicalLibraryName, tape.logicalLibraryName);
     ASSERT_EQ(tapePoolName, tape.tapePoolName);
     ASSERT_EQ(vo, tape.vo);
-    ASSERT_FALSE((bool)tape.encryptionKey);
+    ASSERT_FALSE((bool)tape.encryptionKeyName);
     ASSERT_EQ(capacityInBytes, tape.capacityInBytes);
     ASSERT_TRUE(disabledValue == tape.disabled);
     ASSERT_TRUE(fullValue == tape.full);
@@ -4590,15 +4590,15 @@ TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKey_emptyStringEncryptio
   }
 }
 
-TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKey_nonExistentTape) {
+TEST_P(cta_catalogue_CatalogueTest, modifyTapeEncryptionKeyName_nonExistentTape) {
   using namespace cta;
 
   ASSERT_TRUE(m_catalogue->getTapes().empty());
 
   const std::string vid = "vid";
-  const std::string encryptionKey = "encryption_key";
+  const std::string encryptionKeyName = "encryption_key_name";
 
-  ASSERT_THROW(m_catalogue->modifyTapeEncryptionKey(m_admin, vid, encryptionKey), exception::UserError);
+  ASSERT_THROW(m_catalogue->modifyTapeEncryptionKeyName(m_admin, vid, encryptionKeyName), exception::UserError);
 }
 
 TEST_P(cta_catalogue_CatalogueTest, tapeLabelled) {
diff --git a/catalogue/DummyCatalogue.hpp b/catalogue/DummyCatalogue.hpp
index 9a56ddb476f3d7996d73fcb9521e5dcffa384fe8..e311234a5b48a886a6916168636ded1697c85d6b 100644
--- a/catalogue/DummyCatalogue.hpp
+++ b/catalogue/DummyCatalogue.hpp
@@ -105,7 +105,7 @@ public:
   void modifyStorageClassNbCopies(const common::dataStructures::SecurityIdentity& admin, const std::string& instanceName, const std::string& name, const uint64_t nbCopies) override { throw exception::Exception(std::string("In ")+__PRETTY_FUNCTION__+": not implemented"); }
   void modifyTapeCapacityInBytes(const common::dataStructures::SecurityIdentity& admin, const std::string& vid, const uint64_t capacityInBytes) override { throw exception::Exception(std::string("In ")+__PRETTY_FUNCTION__+": not implemented"); }
   void modifyTapeComment(const common::dataStructures::SecurityIdentity& admin, const std::string& vid, const std::string& comment) override { throw exception::Exception(std::string("In ")+__PRETTY_FUNCTION__+": not implemented"); }
-  void modifyTapeEncryptionKey(const common::dataStructures::SecurityIdentity& admin, const std::string& vid, const std::string& encryptionKey) override { throw exception::Exception(std::string("In ")+__PRETTY_FUNCTION__+": not implemented"); }
+  void modifyTapeEncryptionKeyName(const common::dataStructures::SecurityIdentity& admin, const std::string& vid, const std::string& encryptionKeyName) override { throw exception::Exception(std::string("In ")+__PRETTY_FUNCTION__+": not implemented"); }
   void modifyTapeMediaType(const common::dataStructures::SecurityIdentity& admin, const std::string& vid, const std::string& mediaType) override { throw exception::Exception(std::string("In ")+__PRETTY_FUNCTION__+": not implemented"); }
   void modifyTapeVendor(const common::dataStructures::SecurityIdentity& admin, const std::string& vid, const std::string& vendor) override { throw exception::Exception(std::string("In ")+__PRETTY_FUNCTION__+": not implemented"); }
   void modifyTapeLogicalLibraryName(const common::dataStructures::SecurityIdentity& admin, const std::string& vid, const std::string& logicalLibraryName) override { throw exception::Exception(std::string("In ")+__PRETTY_FUNCTION__+": not implemented"); }
diff --git a/catalogue/MysqlCatalogue.cpp b/catalogue/MysqlCatalogue.cpp
index 5f4f01837b6e31c55c8734fac45a491538442477..47de31109f4890f3ff6f2f52950ba267093dbe68 100644
--- a/catalogue/MysqlCatalogue.cpp
+++ b/catalogue/MysqlCatalogue.cpp
@@ -147,7 +147,7 @@ common::dataStructures::Tape MysqlCatalogue::selectTapeForUpdate(rdbms::Conn &co
       "VID AS VID,"
       "LOGICAL_LIBRARY_NAME AS LOGICAL_LIBRARY_NAME,"
       "TAPE_POOL_NAME AS TAPE_POOL_NAME,"
-      "ENCRYPTION_KEY AS ENCRYPTION_KEY,"
+      "ENCRYPTION_KEY_NAME AS ENCRYPTION_KEY_NAME,"
       "CAPACITY_IN_BYTES AS CAPACITY_IN_BYTES,"
       "DATA_IN_BYTES AS DATA_IN_BYTES,"
       "LAST_FSEQ AS LAST_FSEQ,"
@@ -191,7 +191,7 @@ common::dataStructures::Tape MysqlCatalogue::selectTapeForUpdate(rdbms::Conn &co
     tape.vid = rset.columnString("VID");
     tape.logicalLibraryName = rset.columnString("LOGICAL_LIBRARY_NAME");
     tape.tapePoolName = rset.columnString("TAPE_POOL_NAME");
-    tape.encryptionKey = rset.columnOptionalString("ENCRYPTION_KEY");
+    tape.encryptionKeyName = rset.columnOptionalString("ENCRYPTION_KEY_NAME");
     tape.capacityInBytes = rset.columnUint64("CAPACITY_IN_BYTES");
     tape.dataOnTapeInBytes = rset.columnUint64("DATA_IN_BYTES");
     tape.lastFSeq = rset.columnUint64("LAST_FSEQ");
diff --git a/catalogue/MysqlCatalogue.hpp b/catalogue/MysqlCatalogue.hpp
index 92f9dcff8c9a333ad0f266e533bb9578ab05de98..fc743a52425c80a1e64d0955f7a457152c3c9981 100644
--- a/catalogue/MysqlCatalogue.hpp
+++ b/catalogue/MysqlCatalogue.hpp
@@ -80,7 +80,7 @@ protected:
    * problem of generating ever increasing numeric identifiers.
    *
    * @param conn The database connection.
-   * @return a unique archive ID that can be used by a new archive file within
+   * @return a unique storage class ID that can be used by a new storage class
    * within the catalogue.
    */
   uint64_t getNextStorageClassId(rdbms::Conn &conn) override;
diff --git a/catalogue/OracleCatalogue.cpp b/catalogue/OracleCatalogue.cpp
index 98b28965e2523285084a40695671d5aff17a5328..4ee1c1fc2839f454e0a240adf3b5ab9474e6a8e8 100644
--- a/catalogue/OracleCatalogue.cpp
+++ b/catalogue/OracleCatalogue.cpp
@@ -212,7 +212,7 @@ common::dataStructures::Tape OracleCatalogue::selectTapeForUpdate(rdbms::Conn &c
         "VID AS VID,"
         "LOGICAL_LIBRARY_NAME AS LOGICAL_LIBRARY_NAME,"
         "TAPE_POOL_NAME AS TAPE_POOL_NAME,"
-        "ENCRYPTION_KEY AS ENCRYPTION_KEY,"
+        "ENCRYPTION_KEY_NAME AS ENCRYPTION_KEY_NAME,"
         "CAPACITY_IN_BYTES AS CAPACITY_IN_BYTES,"
         "DATA_IN_BYTES AS DATA_IN_BYTES,"
         "LAST_FSEQ AS LAST_FSEQ,"
@@ -256,7 +256,7 @@ common::dataStructures::Tape OracleCatalogue::selectTapeForUpdate(rdbms::Conn &c
     tape.vid = rset.columnString("VID");
     tape.logicalLibraryName = rset.columnString("LOGICAL_LIBRARY_NAME");
     tape.tapePoolName = rset.columnString("TAPE_POOL_NAME");
-    tape.encryptionKey = rset.columnOptionalString("ENCRYPTION_KEY");
+    tape.encryptionKeyName = rset.columnOptionalString("ENCRYPTION_KEY_NAME");
     tape.capacityInBytes = rset.columnUint64("CAPACITY_IN_BYTES");
     tape.dataOnTapeInBytes = rset.columnUint64("DATA_IN_BYTES");
     tape.lastFSeq = rset.columnUint64("LAST_FSEQ");
diff --git a/catalogue/OracleCatalogue.hpp b/catalogue/OracleCatalogue.hpp
index 473bb9004cff8f59daba0fb76c189a22140b3e5b..0542c7a1881abf6c8beb69553eb859524a4880a2 100644
--- a/catalogue/OracleCatalogue.hpp
+++ b/catalogue/OracleCatalogue.hpp
@@ -80,7 +80,7 @@ public:
    * problem of generating ever increasing numeric identifiers.
    *
    * @param conn The database connection.
-   * @return a unique archive ID that can be used by a new archive file within
+   * @return a unique storage class ID that can be used by a new storage class
    * within the catalogue.
    */
   uint64_t getNextStorageClassId(rdbms::Conn &conn) override;
diff --git a/catalogue/PostgresCatalogue.cpp b/catalogue/PostgresCatalogue.cpp
index 579245dc2a334edcb7685aa6696bc10da72da8c9..8feba18264d8ac31c255bd5d9062e5fd4f232755 100644
--- a/catalogue/PostgresCatalogue.cpp
+++ b/catalogue/PostgresCatalogue.cpp
@@ -202,7 +202,7 @@ common::dataStructures::Tape PostgresCatalogue::selectTapeForUpdate(rdbms::Conn
         "VID AS VID,"
         "LOGICAL_LIBRARY_NAME AS LOGICAL_LIBRARY_NAME,"
         "TAPE_POOL_NAME AS TAPE_POOL_NAME,"
-        "ENCRYPTION_KEY AS ENCRYPTION_KEY,"
+        "ENCRYPTION_KEY_NAME AS ENCRYPTION_KEY_NAME,"
         "CAPACITY_IN_BYTES AS CAPACITY_IN_BYTES,"
         "DATA_IN_BYTES AS DATA_IN_BYTES,"
         "LAST_FSEQ AS LAST_FSEQ,"
@@ -246,7 +246,7 @@ common::dataStructures::Tape PostgresCatalogue::selectTapeForUpdate(rdbms::Conn
     tape.vid = rset.columnString("VID");
     tape.logicalLibraryName = rset.columnString("LOGICAL_LIBRARY_NAME");
     tape.tapePoolName = rset.columnString("TAPE_POOL_NAME");
-    tape.encryptionKey = rset.columnOptionalString("ENCRYPTION_KEY");
+    tape.encryptionKeyName = rset.columnOptionalString("ENCRYPTION_KEY_NAME");
     tape.capacityInBytes = rset.columnUint64("CAPACITY_IN_BYTES");
     tape.dataOnTapeInBytes = rset.columnUint64("DATA_IN_BYTES");
     tape.lastFSeq = rset.columnUint64("LAST_FSEQ");
diff --git a/catalogue/PostgresCatalogue.hpp b/catalogue/PostgresCatalogue.hpp
index 7c1961c73d2833b456c6b99fcc9ce5fd573b0e56..9fa3be58765c053de43218476cb5c43b50767646 100644
--- a/catalogue/PostgresCatalogue.hpp
+++ b/catalogue/PostgresCatalogue.hpp
@@ -106,7 +106,7 @@ public:
    * problem of generating ever increasing numeric identifiers.
    *
    * @param conn The database connection.
-   * @return a unique archive ID that can be used by a new archive file within
+   * @return a unique storage class ID that can be used by a new storage class
    * within the catalogue.
    */
   uint64_t getNextStorageClassId(rdbms::Conn &conn) override;
diff --git a/catalogue/RdbmsCatalogue.cpp b/catalogue/RdbmsCatalogue.cpp
index bac4602501426a44ae0ce1456adf6913c6c660c3..bddf5bd7200a6fef4e0ed4fc503b1d5bb5409550 100644
--- a/catalogue/RdbmsCatalogue.cpp
+++ b/catalogue/RdbmsCatalogue.cpp
@@ -2160,7 +2160,7 @@ std::list<common::dataStructures::Tape> RdbmsCatalogue::getTapes(rdbms::Conn &co
         "TAPE.LOGICAL_LIBRARY_NAME AS LOGICAL_LIBRARY_NAME,"
         "TAPE.TAPE_POOL_NAME AS TAPE_POOL_NAME,"
         "TAPE_POOL.VO AS VO,"
-        "TAPE.ENCRYPTION_KEY AS ENCRYPTION_KEY,"
+        "TAPE.ENCRYPTION_KEY_NAME AS ENCRYPTION_KEY_NAME,"
         "TAPE.CAPACITY_IN_BYTES AS CAPACITY_IN_BYTES,"
         "TAPE.DATA_IN_BYTES AS DATA_IN_BYTES,"
         "TAPE.LAST_FSEQ AS LAST_FSEQ,"
@@ -2285,7 +2285,7 @@ std::list<common::dataStructures::Tape> RdbmsCatalogue::getTapes(rdbms::Conn &co
       tape.logicalLibraryName = rset.columnString("LOGICAL_LIBRARY_NAME");
       tape.tapePoolName = rset.columnString("TAPE_POOL_NAME");
       tape.vo = rset.columnString("VO");
-      tape.encryptionKey = rset.columnOptionalString("ENCRYPTION_KEY");
+      tape.encryptionKeyName = rset.columnOptionalString("ENCRYPTION_KEY_NAME");
       tape.capacityInBytes = rset.columnUint64("CAPACITY_IN_BYTES");
       tape.dataOnTapeInBytes = rset.columnUint64("DATA_IN_BYTES");
       tape.lastFSeq = rset.columnUint64("LAST_FSEQ");
@@ -2335,7 +2335,7 @@ common::dataStructures::VidToTapeMap RdbmsCatalogue::getTapesByVid(const std::se
         "TAPE.LOGICAL_LIBRARY_NAME AS LOGICAL_LIBRARY_NAME,"
         "TAPE.TAPE_POOL_NAME AS TAPE_POOL_NAME,"
         "TAPE_POOL.VO AS VO,"
-        "TAPE.ENCRYPTION_KEY AS ENCRYPTION_KEY,"
+        "TAPE.ENCRYPTION_KEY_NAME AS ENCRYPTION_KEY_NAME,"
         "TAPE.CAPACITY_IN_BYTES AS CAPACITY_IN_BYTES,"
         "TAPE.DATA_IN_BYTES AS DATA_IN_BYTES,"
         "TAPE.LAST_FSEQ AS LAST_FSEQ,"
@@ -2407,7 +2407,7 @@ common::dataStructures::VidToTapeMap RdbmsCatalogue::getTapesByVid(const std::se
       tape.logicalLibraryName = rset.columnString("LOGICAL_LIBRARY_NAME");
       tape.tapePoolName = rset.columnString("TAPE_POOL_NAME");
       tape.vo = rset.columnString("VO");
-      tape.encryptionKey = rset.columnOptionalString("ENCRYPTION_KEY");
+      tape.encryptionKeyName = rset.columnOptionalString("ENCRYPTION_KEY_NAME");
       tape.capacityInBytes = rset.columnUint64("CAPACITY_IN_BYTES");
       tape.dataOnTapeInBytes = rset.columnUint64("DATA_IN_BYTES");
       tape.lastFSeq = rset.columnUint64("LAST_FSEQ");
@@ -2461,7 +2461,7 @@ common::dataStructures::VidToTapeMap RdbmsCatalogue::getAllTapes() const {
         "TAPE.LOGICAL_LIBRARY_NAME AS LOGICAL_LIBRARY_NAME,"
         "TAPE.TAPE_POOL_NAME AS TAPE_POOL_NAME,"
         "TAPE_POOL.VO AS VO,"
-        "TAPE.ENCRYPTION_KEY AS ENCRYPTION_KEY,"
+        "TAPE.ENCRYPTION_KEY_NAME AS ENCRYPTION_KEY_NAME,"
         "TAPE.CAPACITY_IN_BYTES AS CAPACITY_IN_BYTES,"
         "TAPE.DATA_IN_BYTES AS DATA_IN_BYTES,"
         "TAPE.LAST_FSEQ AS LAST_FSEQ,"
@@ -2509,7 +2509,7 @@ common::dataStructures::VidToTapeMap RdbmsCatalogue::getAllTapes() const {
       tape.logicalLibraryName = rset.columnString("LOGICAL_LIBRARY_NAME");
       tape.tapePoolName = rset.columnString("TAPE_POOL_NAME");
       tape.vo = rset.columnString("VO");
-      tape.encryptionKey = rset.columnOptionalString("ENCRYPTION_KEY");
+      tape.encryptionKeyName = rset.columnOptionalString("ENCRYPTION_KEY_NAME");
       tape.capacityInBytes = rset.columnUint64("CAPACITY_IN_BYTES");
       tape.dataOnTapeInBytes = rset.columnUint64("DATA_IN_BYTES");
       tape.lastFSeq = rset.columnUint64("LAST_FSEQ");
@@ -2968,20 +2968,20 @@ void RdbmsCatalogue::modifyTapeCapacityInBytes(const common::dataStructures::Sec
 }
 
 //------------------------------------------------------------------------------
-// modifyTapeEncryptionKey
+// modifyTapeEncryptionKeyName
 //------------------------------------------------------------------------------
-void RdbmsCatalogue::modifyTapeEncryptionKey(const common::dataStructures::SecurityIdentity &admin,
-  const std::string &vid, const std::string &encryptionKey) {
+void RdbmsCatalogue::modifyTapeEncryptionKeyName(const common::dataStructures::SecurityIdentity &admin,
+  const std::string &vid, const std::string &encryptionKeyName) {
   try {
-    optional<std::string> optionalEncryptionKey;
-    if(!encryptionKey.empty()) {
-      optionalEncryptionKey = encryptionKey;
+    optional<std::string> optionalEncryptionKeyName;
+    if(!encryptionKeyName.empty()) {
+      optionalEncryptionKeyName = encryptionKeyName;
     }
 
     const time_t now = time(nullptr);
     const char *const sql =
       "UPDATE TAPE SET "
-        "ENCRYPTION_KEY = :ENCRYPTION_KEY,"
+        "ENCRYPTION_KEY_NAME = :ENCRYPTION_KEY_NAME,"
         "LAST_UPDATE_USER_NAME = :LAST_UPDATE_USER_NAME,"
         "LAST_UPDATE_HOST_NAME = :LAST_UPDATE_HOST_NAME,"
         "LAST_UPDATE_TIME = :LAST_UPDATE_TIME "
@@ -2989,7 +2989,7 @@ void RdbmsCatalogue::modifyTapeEncryptionKey(const common::dataStructures::Secur
         "VID = :VID";
     auto conn = m_connPool.getConn();
     auto stmt = conn.createStmt(sql);
-    stmt.bindOptionalString(":ENCRYPTION_KEY", optionalEncryptionKey);
+    stmt.bindOptionalString(":ENCRYPTION_KEY_NAME", optionalEncryptionKeyName);
     stmt.bindString(":LAST_UPDATE_USER_NAME", admin.username);
     stmt.bindString(":LAST_UPDATE_HOST_NAME", admin.host);
     stmt.bindUint64(":LAST_UPDATE_TIME", now);
@@ -3003,11 +3003,11 @@ void RdbmsCatalogue::modifyTapeEncryptionKey(const common::dataStructures::Secur
     log::LogContext lc(m_log);
     log::ScopedParamContainer spc(lc);
     spc.add("vid", vid)
-       .add("encryptionKey", optionalEncryptionKey ? optionalEncryptionKey.value() : "NULL")
+       .add("encryptionKeyName", optionalEncryptionKeyName ? optionalEncryptionKeyName.value() : "NULL")
        .add("lastUpdateUserName", admin.username)
        .add("lastUpdateHostName", admin.host)
        .add("lastUpdateTime", now);
-    lc.log(log::INFO, "Catalogue - user modified tape - encryptionKey");
+    lc.log(log::INFO, "Catalogue - user modified tape - encryptionKeyName");
   } catch(exception::UserError &) {
     throw;
   } catch(exception::Exception &ex) {
diff --git a/catalogue/RdbmsCatalogue.hpp b/catalogue/RdbmsCatalogue.hpp
index 8fdda7a41f5f1ec3ef0f903f62c65afde5aba884..7afcd87fc06ac31599608ad39b62bb252932a14f 100644
--- a/catalogue/RdbmsCatalogue.hpp
+++ b/catalogue/RdbmsCatalogue.hpp
@@ -399,7 +399,7 @@ public:
   void modifyTapeLogicalLibraryName(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &logicalLibraryName) override;
   void modifyTapeTapePoolName(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &tapePoolName) override;
   void modifyTapeCapacityInBytes(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const uint64_t capacityInBytes) override;
-  void modifyTapeEncryptionKey(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &encryptionKey) override;
+  void modifyTapeEncryptionKeyName(const common::dataStructures::SecurityIdentity &admin, const std::string &vid, const std::string &encryptionKeyName) override;
 
   /**
    * Sets the full status of the specified tape.
@@ -1335,7 +1335,7 @@ protected:
    * problem of generating ever increasing numeric identifiers.
    *
    * @param conn The database connection.
-   * @return a unique archive ID that can be used by a new archive file within
+   * @return a unique storage class ID that can be used by a new storage class
    * within the catalogue.
    */
   virtual uint64_t getNextStorageClassId(rdbms::Conn &conn) = 0;
diff --git a/catalogue/SqliteCatalogue.cpp b/catalogue/SqliteCatalogue.cpp
index 541329ba7dea0585671d523d5457ed6fa9b1d236..978778d18c2c995aeb8fd9250f235b83d6522025 100644
--- a/catalogue/SqliteCatalogue.cpp
+++ b/catalogue/SqliteCatalogue.cpp
@@ -250,7 +250,7 @@ common::dataStructures::Tape SqliteCatalogue::selectTape(rdbms::Conn &conn, cons
         "VID AS VID,"
         "LOGICAL_LIBRARY_NAME AS LOGICAL_LIBRARY_NAME,"
         "TAPE_POOL_NAME AS TAPE_POOL_NAME,"
-        "ENCRYPTION_KEY AS ENCRYPTION_KEY,"
+        "ENCRYPTION_KEY_NAME AS ENCRYPTION_KEY_NAME,"
         "CAPACITY_IN_BYTES AS CAPACITY_IN_BYTES,"
         "DATA_IN_BYTES AS DATA_IN_BYTES,"
         "LAST_FSEQ AS LAST_FSEQ,"
@@ -294,7 +294,7 @@ common::dataStructures::Tape SqliteCatalogue::selectTape(rdbms::Conn &conn, cons
     tape.vid = rset.columnString("VID");
     tape.logicalLibraryName = rset.columnString("LOGICAL_LIBRARY_NAME");
     tape.tapePoolName = rset.columnString("TAPE_POOL_NAME");
-    tape.encryptionKey = rset.columnOptionalString("ENCRYPTION_KEY");
+    tape.encryptionKeyName = rset.columnOptionalString("ENCRYPTION_KEY_NAME");
     tape.capacityInBytes = rset.columnUint64("CAPACITY_IN_BYTES");
     tape.dataOnTapeInBytes = rset.columnUint64("DATA_IN_BYTES");
     tape.lastFSeq = rset.columnUint64("LAST_FSEQ");
diff --git a/catalogue/SqliteCatalogue.hpp b/catalogue/SqliteCatalogue.hpp
index 88e91d083d8aecb7dad5602a28f35cea243f0774..5446e0b8d6d425178c5b11fa51257e654b7176c6 100644
--- a/catalogue/SqliteCatalogue.hpp
+++ b/catalogue/SqliteCatalogue.hpp
@@ -109,7 +109,7 @@ protected:
    * problem of generating ever increasing numeric identifiers.
    *
    * @param conn The database connection.
-   * @return a unique archive ID that can be used by a new archive file within
+   * @return a unique storage class ID that can be used by a new storage class
    * within the catalogue.
    */
   uint64_t getNextStorageClassId(rdbms::Conn &conn) override;
diff --git a/catalogue/common_catalogue_schema.sql b/catalogue/common_catalogue_schema.sql
index d5d1a6c10c5bc9fd58144c26ec470de75a9ecb7c..37d2d22298149102baf451424059a15fae1d6d3e 100644
--- a/catalogue/common_catalogue_schema.sql
+++ b/catalogue/common_catalogue_schema.sql
@@ -96,7 +96,7 @@ CREATE TABLE TAPE(
   VENDOR                  VARCHAR(100)    CONSTRAINT TAPE_V2_NN   NOT NULL,
   LOGICAL_LIBRARY_NAME    VARCHAR(100)    CONSTRAINT TAPE_LLN_NN  NOT NULL,
   TAPE_POOL_NAME          VARCHAR(100)    CONSTRAINT TAPE_TPN_NN  NOT NULL,
-  ENCRYPTION_KEY          VARCHAR(100),
+  ENCRYPTION_KEY_NAME     VARCHAR(100),
   CAPACITY_IN_BYTES       UINT64TYPE      CONSTRAINT TAPE_CIB_NN  NOT NULL,
   DATA_IN_BYTES           UINT64TYPE      CONSTRAINT TAPE_DIB_NN  NOT NULL,
   LAST_FSEQ               UINT64TYPE      CONSTRAINT TAPE_LF_NN   NOT NULL,
diff --git a/catalogue/rdbms_classes.pptx b/catalogue/rdbms_classes.pptx
index 04f617ad4950bc0ec06fd88688631b357d188fad..a0fd81576150e58cceba195ac47adbc886eafdb3 100644
Binary files a/catalogue/rdbms_classes.pptx and b/catalogue/rdbms_classes.pptx differ
diff --git a/cmdline/CtaAdminCmdParse.hpp b/cmdline/CtaAdminCmdParse.hpp
index fa080f80849714aeff28ca1d95b1d1ec7a57ce17..58b9a90f1e2a772b854ad94359fb98ce477a80e1 100644
--- a/cmdline/CtaAdminCmdParse.hpp
+++ b/cmdline/CtaAdminCmdParse.hpp
@@ -297,7 +297,7 @@ const std::map<std::string, OptionString::Key> strOptions = {
    { "--comment",               OptionString::COMMENT },
    { "--diskid",                OptionString::DISKID },
    { "--drive",                 OptionString::DRIVE },
-   { "--encryptionkey",         OptionString::ENCRYPTION_KEY },
+   { "--encryptionkeyname",     OptionString::ENCRYPTION_KEY_NAME },
    { "--file",                  OptionString::FILENAME },
    { "--hostname",              OptionString::HOSTNAME },
    { "--input",                 OptionString::INPUT },
@@ -389,7 +389,7 @@ const Option opt_diskid               { Option::OPT_STR,  "--diskid",
 const Option opt_drivename            { Option::OPT_STR,  "--drive",                 "-d",   " <drive_name>" };
 const Option opt_drivename_cmd        { Option::OPT_CMD,  "--drive",                 "",     "<drive_name>" };
 const Option opt_encrypted            { Option::OPT_BOOL, "--encrypted",             "-e",   " <\"true\" or \"false\">" };
-const Option opt_encryptionkey        { Option::OPT_STR,  "--encryptionkey",         "-k",   " <encryption_key>" };
+const Option opt_encryptionkeyname    { Option::OPT_STR,  "--encryptionkeyname",     "-k",   " <encryption_key_name>" };
 const Option opt_extended             { Option::OPT_FLAG, "--extended",              "-x",   "" };
 const Option opt_filename             { Option::OPT_STR,  "--file",                  "-f",   " <filename>" };
 const Option opt_firstfseq            { Option::OPT_UINT, "--firstfseq",             "-f",   " <first_fseq>" };
@@ -543,7 +543,7 @@ const std::map<cmd_key_t, cmd_val_t> cmdOptions = {
         opt_comment.optional() }},
    {{ AdminCmd::CMD_TAPE,                 AdminCmd::SUBCMD_CH    },
       { opt_vid, opt_mediatype.optional(), opt_vendor.optional(), opt_logicallibrary.optional(),
-        opt_tapepool.optional(), opt_capacity.optional(), opt_encryptionkey.optional(), opt_disabled.optional(),
+        opt_tapepool.optional(), opt_capacity.optional(), opt_encryptionkeyname.optional(), opt_disabled.optional(),
         opt_full.optional(), opt_readonly.optional(), opt_comment.optional() }},
    {{ AdminCmd::CMD_TAPE,                 AdminCmd::SUBCMD_RM    }, { opt_vid }},
    {{ AdminCmd::CMD_TAPE,                 AdminCmd::SUBCMD_RECLAIM }, { opt_vid }},
diff --git a/cmdline/CtaAdminTextFormatter.cpp b/cmdline/CtaAdminTextFormatter.cpp
index 810c0c8a3de5362633dbf446d3cccc2676556a78..b4061446805648be94aa4fe74e83f1919e507f6b 100644
--- a/cmdline/CtaAdminTextFormatter.cpp
+++ b/cmdline/CtaAdminTextFormatter.cpp
@@ -780,7 +780,7 @@ void TextFormatter::printTapeLsHeader() {
     "library",
     "tapepool",
     "vo",
-    "encryption key",
+    "encryption key name",
     "capacity",
     "occupancy",
     "last fseq",
@@ -814,7 +814,7 @@ void TextFormatter::print(const TapeLsItem &tals_item) {
     tals_item.logical_library(),
     tals_item.tapepool(),
     tals_item.vo(),
-    tals_item.encryption_key(),
+    tals_item.encryption_key_name(),
     dataSizeToStr(tals_item.capacity()),
     dataSizeToStr(tals_item.occupancy()),
     tals_item.last_fseq(),
diff --git a/common/dataStructures/Tape.cpp b/common/dataStructures/Tape.cpp
index 3df67facd87a0cdd7ac816698586eb1bb8f606a2..b8afb13c43e93d56f9ef8f74b17420502e796738 100644
--- a/common/dataStructures/Tape.cpp
+++ b/common/dataStructures/Tape.cpp
@@ -45,7 +45,7 @@ bool Tape::operator==(const Tape &rhs) const {
       && tapePoolName==rhs.tapePoolName
       && capacityInBytes==rhs.capacityInBytes
       && dataOnTapeInBytes==rhs.dataOnTapeInBytes
-      && encryptionKey==rhs.encryptionKey
+      && encryptionKeyName==rhs.encryptionKeyName
       && full==rhs.full
       && disabled==rhs.disabled
       && readOnly==rhs.readOnly
@@ -74,7 +74,7 @@ std::ostream &operator<<(std::ostream &os, const Tape &obj) {
      << " tapePoolName=" << obj.tapePoolName
      << " capacityInBytes=" << obj.capacityInBytes
      << " dataOnTapeInBytes=" << obj.dataOnTapeInBytes
-     << " encryptionKey=" << (obj.encryptionKey ? obj.encryptionKey.value() : "null")
+     << " encryptionKeyName=" << (obj.encryptionKeyName ? obj.encryptionKeyName.value() : "null")
      << " full=" << obj.full
      << " disabled=" << obj.disabled
      << " readOnly=" << obj.readOnly    
diff --git a/continuousintegration/docker/ctafrontend/cc7/opt/run/bin/oracleunittests.sh b/continuousintegration/docker/ctafrontend/cc7/opt/run/bin/oracleunittests.sh
index 36641b00a687e31fa5a63bc734abec828632a4a2..f88888392784d9399ce13072aa5c68278ed122b6 100755
--- a/continuousintegration/docker/ctafrontend/cc7/opt/run/bin/oracleunittests.sh
+++ b/continuousintegration/docker/ctafrontend/cc7/opt/run/bin/oracleunittests.sh
@@ -1,5 +1,21 @@
 #!/bin/bash 
 
+# The CERN Tape Archive (CTA) project
+# Copyright (C) 2015  CERN
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 set -e
 
 . /opt/run/bin/init_pod.sh
@@ -21,7 +37,10 @@ echo ${DATABASEURL} > /etc/cta/cta-catalogue.conf
 
 yum -y install cta-catalogueutils cta-systemtests
 
-/usr/bin/cta-rdbmsUnitTests /etc/cta/cta-catalogue.conf
+2>&1 /usr/bin/cta-rdbmsUnitTests /etc/cta/cta-catalogue.conf | awk '{print "oracle " $0;}'
+
+# Disabled/commented out the valgrind tests of Oracle until they work better with CI
+#2>&1 /usr/bin/cta-rdbmsUnitTests-oracle.sh /etc/cta/cta-catalogue.conf | awk '{print "valgrind oracle " $0;}'
 
 echo 'yes' | /usr/bin/cta-catalogue-schema-drop /etc/cta/cta-catalogue.conf
 /usr/bin/cta-catalogue-schema-create /etc/cta/cta-catalogue.conf
diff --git a/cta.spec.in b/cta.spec.in
index 11188341fcba27439eec49101f5ceaa643354740..6a8c3e7476a3fdc75f7b25c49f9d48ffa8d01385 100644
--- a/cta.spec.in
+++ b/cta.spec.in
@@ -231,6 +231,7 @@ Unit tests and system tests with virtual tape drives
 %{_libdir}/libsystemTestHelperTests.so*
 %{_libdir}/libcta-tapedSystemTests.so*
 %{_bindir}/cta-rdbmsUnitTests
+%{_bindir}/cta-rdbmsUnitTests-oracle.sh
 %{_bindir}/cta-unitTests
 %{_bindir}/cta-unitTests-multiProcess
 %{_bindir}/cta-valgrindUnitTests.sh
diff --git a/tests/CMakeLists.txt b/tests/CMakeLists.txt
index fd7308506026681fd3f92a69fda01c0818b81153..9b9ceae41d2ffba00e90418a35be220de369f7b5 100644
--- a/tests/CMakeLists.txt
+++ b/tests/CMakeLists.txt
@@ -118,9 +118,10 @@ install(TARGETS cta-rdbmsUnitTests cta-unitTests cta-unitTests-multiProcess cta-
 
 install(TARGETS systemTestHelperTests DESTINATION usr/${CMAKE_INSTALL_LIBDIR})
 
+configure_file(cta-rdbmsUnitTests-oracle.sh.in ${CMAKE_CURRENT_BINARY_DIR}/cta-rdbmsUnitTests-oracle.sh @ONLY)
 configure_file(cta-valgrindUnitTests.sh.in ${CMAKE_CURRENT_BINARY_DIR}/cta-valgrindUnitTests.sh)
 configure_file(parallelTestsMakefile.in ${CMAKE_CURRENT_BINARY_DIR}/parallelTestsMakefile @ONLY)
 configure_file(parallelTestsMakefile.local.in ${CMAKE_CURRENT_BINARY_DIR}/parallelTestsMakefile.local @ONLY)
 
-install(FILES ${CMAKE_CURRENT_BINARY_DIR}/cta-valgrindUnitTests.sh cta-unitPlusSystemTests.sh DESTINATION usr/bin)
-install(FILES valgrind.suppr helgrind.suppr ${CMAKE_CURRENT_BINARY_DIR}/parallelTestsMakefile DESTINATION usr/share/cta-${CTA_VERSION}/unittest/)
+install(FILES ${CMAKE_CURRENT_BINARY_DIR}/cta-rdbmsUnitTests-oracle.sh ${CMAKE_CURRENT_BINARY_DIR}/cta-valgrindUnitTests.sh cta-unitPlusSystemTests.sh DESTINATION usr/bin)
+install(FILES cta-rdbmsUnitTests-oracle.suppr valgrind.suppr helgrind.suppr ${CMAKE_CURRENT_BINARY_DIR}/parallelTestsMakefile DESTINATION usr/share/cta-${CTA_VERSION}/unittest/)
diff --git a/tests/cta-rdbmsUnitTests-oracle.sh.in b/tests/cta-rdbmsUnitTests-oracle.sh.in
new file mode 100755
index 0000000000000000000000000000000000000000..dfe1dcd7835d5fbde07f7285a8d932e069dcd876
--- /dev/null
+++ b/tests/cta-rdbmsUnitTests-oracle.sh.in
@@ -0,0 +1,29 @@
+#!/bin/bash
+
+# The CERN Tape Archive (CTA) project
+# Copyright (C) 2015  CERN
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+set -e
+
+if test $# -ne 1; then
+  echo "Wrong number of command-line arguments: expected=1 actual=$#"
+  echo "Usage: cta-rdbmsUnitTests-oracle.sh databaseConnectionFile"
+  exit 1
+fi
+
+DB_CONN_FILE=$1
+
+valgrind --gen-suppressions=all --suppressions=/usr/share/cta-@CTA_VERSION@/unittest/cta-rdbmsUnitTests-oracle.suppr /usr/bin/cta-rdbmsUnitTests ${DB_CONN_FILE}
diff --git a/tests/cta-rdbmsUnitTests-oracle.suppr b/tests/cta-rdbmsUnitTests-oracle.suppr
new file mode 100644
index 0000000000000000000000000000000000000000..79d4a4abad51210ccd98abb10c89c233bb043ff6
--- /dev/null
+++ b/tests/cta-rdbmsUnitTests-oracle.suppr
@@ -0,0 +1,1258 @@
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strcpy
+   fun:lfvLoadPkg
+   fun:lfvSetShlMode
+   fun:lfvini1
+   fun:lfvinit
+   fun:kpummpin
+   fun:kpuenvcr
+   fun:OCIEnvCreate
+   fun:_ZN6oracle4occi11Environment17createEnvironmentENS1_4ModeEPvPFS3_S3_mEPFS3_S3_S3_mEPFvS3_S3_E
+   fun:_ZN3cta5rdbms7wrapper7OcciEnvC1Ev
+   fun:_ZN3cta5rdbms7wrapper16OcciEnvSingletonC1Ev
+   fun:_ZN3cta5rdbms7wrapper16OcciEnvSingleton8instanceEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:lmmmalloc
+   fun:lmmcis
+   fun:lpmpali
+   fun:lpminitm
+   fun:lfvLoadPkg
+   fun:lfvSetShlMode
+   fun:lfvini1
+   fun:lfvinit
+   fun:kpummpin
+   fun:kpuenvcr
+   fun:OCIEnvCreate
+   fun:_ZN6oracle4occi11Environment17createEnvironmentENS1_4ModeEPvPFS3_S3_mEPFS3_S3_S3_mEPFvS3_S3_E
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:lmmmalloc
+   fun:lmmhpinit
+   fun:lmmcis
+   fun:lpmpali
+   fun:lpminitm
+   fun:lfvLoadPkg
+   fun:lfvSetShlMode
+   fun:lfvini1
+   fun:lfvinit
+   fun:kpummpin
+   fun:kpuenvcr
+   fun:OCIEnvCreate
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:lmmmalloc
+   fun:lmmsthinit
+   fun:lmmhpinit
+   fun:lmmcis
+   fun:lpmpali
+   fun:lpminitm
+   fun:lfvLoadPkg
+   fun:lfvSetShlMode
+   fun:lfvini1
+   fun:lfvinit
+   fun:kpummpin
+   fun:kpuenvcr
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strcpy
+   fun:slpmadp
+   fun:lpmapd
+   fun:lfvLoadPkg
+   fun:lfvSetShlMode
+   fun:lfvini1
+   fun:lfvinit
+   fun:kpummpin
+   fun:kpuenvcr
+   fun:OCIEnvCreate
+   fun:_ZN6oracle4occi11Environment17createEnvironmentENS1_4ModeEPvPFS3_S3_mEPFS3_S3_S3_mEPFvS3_S3_E
+   fun:_ZN3cta5rdbms7wrapper7OcciEnvC1Ev
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:lmmmalloc
+   fun:lmmcis
+   fun:lpmpali
+   fun:lpmloadpkg
+   fun:lfvLoadPkg
+   fun:lfvSetShlMode
+   fun:lfvini1
+   fun:lfvinit
+   fun:kpummpin
+   fun:kpuenvcr
+   fun:OCIEnvCreate
+   fun:_ZN6oracle4occi11Environment17createEnvironmentENS1_4ModeEPvPFS3_S3_mEPFS3_S3_S3_mEPFvS3_S3_E
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strncpy
+   fun:lfvpkgname
+   fun:kpummpin
+   fun:kpuenvcr
+   fun:OCIEnvCreate
+   fun:_ZN6oracle4occi11Environment17createEnvironmentENS1_4ModeEPvPFS3_S3_mEPFS3_S3_S3_mEPFvS3_S3_E
+   fun:_ZN3cta5rdbms7wrapper7OcciEnvC1Ev
+   fun:_ZN3cta5rdbms7wrapper16OcciEnvSingletonC1Ev
+   fun:_ZN3cta5rdbms7wrapper16OcciEnvSingleton8instanceEv
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+   fun:_ZN9unitTests18cta_rdbms_StmtTest5SetUpEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strncpy
+   fun:lfvpkgname
+   fun:slxcfot
+   fun:lxldLoadBoot
+   fun:lxlinit
+   fun:nleminz
+   fun:nlstdggo
+   fun:nlstdgg
+   fun:nigini2
+   fun:kpeDbgTLSInit
+   fun:kpummTLSGET1
+   fun:kpeDbgProcessInit
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strncpy
+   fun:lfvpkgname
+   fun:slxcfot
+   fun:lxlfOpen
+   fun:lxldlod
+   fun:lxdlobj
+   fun:lxdgetobj
+   fun:lxplset
+   fun:lxhLaToId
+   fun:lxhenvquery
+   fun:lxhLangEnv
+   fun:nleminz
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strncmp
+   fun:lxlchkobj
+   fun:lxlfrd
+   fun:lxldlod
+   fun:lxdlobj
+   fun:lxdgetobj
+   fun:lxhLaToId
+   fun:lxhenvquery
+   fun:lxhLangEnv
+   fun:nleminz
+   fun:nlstdggo
+   fun:nlstdgg
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strcat
+   fun:slgfn
+   fun:dbgrgad_get_adrbase_directory
+   fun:kpeDbgGetInitFileParms
+   fun:kpeDbgGetInitFileParmsAndInitDBGC
+   fun:nlstddd_do_alter_diag
+   fun:nlstddt_do_alter_trace
+   fun:nlstdggo
+   fun:nlstdgg
+   fun:nigini2
+   fun:kpeDbgTLSInit
+   fun:kpummTLSGET1
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strcat
+   fun:slgfn
+   fun:dbgrgad_get_adrbase_directory
+   fun:nlddinit
+   fun:nlstddd_do_alter_diag
+   fun:nlstddt_do_alter_trace
+   fun:nlstdggo
+   fun:nlstdgg
+   fun:nigini2
+   fun:kpeDbgTLSInit
+   fun:kpummTLSGET1
+   fun:kpeDbgProcessInit
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:r0_des_set_key
+   fun:r0_cipher_des_set_key
+   fun:R1_CIPH_CTX_set_key_bytes_state
+   fun:r_ck_cipher_init_base
+   fun:r_ck_cipher_init_des
+   fun:ri_cr_ciph_init
+   fun:R_CR_encrypt_init
+   fun:ztca_RSAAdpSecKeyOpInit_2
+   fun:ztca_SecKeyEncryptCtxInitMC_2
+   fun:ztca_SecKeyEncryptCtxInit_2
+   fun:ztcebi_2
+   fun:ztcei2
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:r0_des_encp_k8_64
+   fun:r0_cipher_cbc8lup_enc
+   fun:r0_cipher_cbc8lup
+   fun:R1_CIPH_CTX_cipher
+   fun:r_ck_cipher_update
+   fun:ztca_RSAAdpEncrypt
+   fun:ztcebn
+   fun:ztcecrypto_2
+   fun:ztceenc
+   fun:ztcrbm
+   fun:ztcrbh
+   fun:ztcrbp
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:_intel_fast_memcmp
+   fun:ztcrbh
+   fun:ztcrbp
+   fun:ztcrseed3
+   fun:ztcsh
+   fun:kpusattr
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztcrbh
+   fun:ztcrbp
+   fun:ztcrseed3
+   fun:ztcsh
+   fun:kpusattr
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+   fun:_ZN9unitTests18cta_rdbms_StmtTest5SetUpEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strncpy
+   fun:nttbnd2addr
+   fun:ntacbbnd2addr
+   fun:ntacbnd2addr
+   fun:nsgettrans_bystring
+   fun:niotns
+   fun:osncon
+   fun:kpuadef
+   fun:upiini
+   fun:kpuatch
+   fun:kpuspsessionget
+   fun:OCISessionGet
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_ssse3_rep_memcpy
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_ssse3_rep_memcpy
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_ssse3_rep_memcpy
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpugskey
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpugskey
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:kzsr5gvfr
+   fun:kpugskey
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:lxgcnvb
+   fun:lxgConvertToAL32UTF8
+   fun:kzsr5gvfr
+   fun:kpugskey
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_ssse3_rep_memcpy
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:ztcsc
+   fun:ztcsr
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:lxgcnvb
+   fun:lxgConvertToAL32UTF8
+   fun:kzsr5gvfr
+   fun:kpugskey
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_memset
+   fun:kpugskey
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_memset
+   fun:kpugskey
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:_intel_fast_memcmp
+   fun:kztvo5weak
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:kztvo5weak
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:_intel_fast_memcmp
+   fun:kztvo5weak
+   fun:kztvo5csk
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:kztvo5weak
+   fun:kztvo5csk
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:ztucbtx
+   fun:kztvo5csk
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:ztucbtx
+   fun:kztvo5ke
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:ztucbtx
+   fun:kztvo5_pbkdf2_skey_enc
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:lxgcnvb
+   fun:lxgcnv
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:lxgcnvb
+   fun:lxgcnv
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:ztucbtx
+   fun:kztvo5pe
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_memset
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_memset
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strncpy
+   fun:lfvpkgname
+   fun:kpusclt
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:lmmfree
+   fun:lmmsthfree
+   fun:lmmhpfree
+   fun:lmmcit
+   fun:lpmpfin
+   fun:lpmdelete
+   fun:kpubalts
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:lmmfree
+   fun:lmmhpfree
+   fun:lmmcit
+   fun:lpmpfin
+   fun:lpmdelete
+   fun:kpubalts
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:lmmfree
+   fun:lmmcit
+   fun:lpmpfin
+   fun:lpmdelete
+   fun:kpubalts
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_memset
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+   fun:_ZN9unitTests18cta_rdbms_StmtTest5SetUpEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_memset
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+   fun:_ZN9unitTests18cta_rdbms_StmtTest5SetUpEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strcpy
+   fun:nlolgobj
+   fun:nnfun2a
+   fun:niqname
+   fun:kpuctcmn
+   fun:kpuatch
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_sse2_strcpy
+   fun:nlolgserv
+   fun:nlolgobj
+   fun:nnfun2a
+   fun:niqname
+   fun:kpuctcmn
+   fun:kpuatch
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:kztvo5ed
+   fun:kztvo5ver
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:kztvo5ed
+   fun:kztvo5ver
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:kztvo5ed
+   fun:kztvo5ver
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:kztvo5ed
+   fun:kztvo5ver
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:kztvo5ed
+   fun:kztvo5ver
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztceb_unpadding
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:kztvo5ed
+   fun:kztvo5ver
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztcecrypto_2
+   fun:ztcedec
+   fun:kztvo5ed
+   fun:kztvo5ver
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:kztvo5ver
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:_intel_fast_memcmp
+   fun:kztvo5ver
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+   fun:_ZN3cta5rdbms8ConnPool7getConnEv
+   fun:_ZN9unitTests18cta_rdbms_StmtTest5SetUpEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:nassky
+   fun:nszssk
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+   fun:_ZN3cta5rdbms7wrapper7OcciEnv10createConnERKSsS4_S4_
+   fun:_ZN3cta5rdbms7wrapper15OcciConnFactory6createEv
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_memset
+   fun:ztceb_padding
+   fun:kztvo5pe
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_memset
+   fun:ztceb_padding
+   fun:kztvo5pe
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_memset
+   fun:ztceb_padding
+   fun:kztvo5pe
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:ztcebn
+   fun:ztceb_padding
+   fun:kztvo5pe
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+   fun:_ZN6oracle4occi15EnvironmentImpl16createConnectionERKSsS3_S3_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_ssse3_rep_memcpy
+   fun:ztcebn
+   fun:ztceb_padding
+   fun:kztvo5pe
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_ssse3_rep_memcpy
+   fun:ztcebn
+   fun:ztceb_padding
+   fun:kztvo5pe
+   fun:kzsrepw
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+   fun:_ZN6oracle4occi14ConnectionImplC1EPNS0_15EnvironmentImplERKSsS5_S5_
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:nsbasic_bsd
+   fun:nioqrc
+   fun:ttcdrv
+   fun:nioqwa
+   fun:upirtrc
+   fun:upirtr
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+   fun:OCISessionGet
+   fun:_ZN6oracle4occi14ConnectionImpl14openConnectionEP6OCIEnvP8OCIErrorPvjS6_jS6_jS6_jjS6_jNS0_10Connection6PurityENS0_23StatelessConnectionPool8PoolTypeE
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Value8
+   fun:__intel_ssse3_rep_memcpy
+   fun:ttcc2u
+   fun:ttcrbur
+   fun:ttcpip
+   fun:ttcdrv
+   fun:nioqwa
+   fun:upirtrc
+   fun:upirtr
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+}
+
+{
+   <insert_a_suppression_name_here>
+   Memcheck:Cond
+   fun:__intel_ssse3_rep_memcpy
+   fun:ttcc2u
+   fun:ttcrbur
+   fun:ttcpip
+   fun:ttcdrv
+   fun:nioqwa
+   fun:upirtrc
+   fun:upirtr
+   fun:kpu8lgn
+   fun:kpuauthxa
+   fun:kpuauth
+   fun:kpuspsessionget
+}
+
diff --git a/tests/rdbmsUnitTests.cpp b/tests/rdbmsUnitTests.cpp
index d80ae36d08a1cbf278e1b721c3cba42bcc2193af..2b82544de16565984461283b287b3cf3aac941a0 100644
--- a/tests/rdbmsUnitTests.cpp
+++ b/tests/rdbmsUnitTests.cpp
@@ -41,8 +41,13 @@ static void printUsage(std::ostream &os) {
  * command-line.
  */
 static RdbmsUnitTestsCmdLineArgs parseCmdLine(const int argc, char ** argv) {
-  if(argc != 2) {
-    std::cerr << "Invalid number of command-line arguments";
+  const int expectedNbArgs = 1;
+  const int actualNbArgs = argc - 1;
+
+  if(expectedNbArgs != actualNbArgs) {
+    std::cerr << "Invalid number of command-line arguments: expected=" << expectedNbArgs << " actual=" << actualNbArgs
+      << std::endl;
+    std::cerr << std::endl;
     printUsage(std::cerr);
     exit(1);
   }
diff --git a/xroot_plugins/XrdCtaTapeLs.hpp b/xroot_plugins/XrdCtaTapeLs.hpp
index 06e4157da7bdaea32162b9f828921d362842e2e1..06f82f2c3195ebc0f8e2598600d0b759816ed981 100644
--- a/xroot_plugins/XrdCtaTapeLs.hpp
+++ b/xroot_plugins/XrdCtaTapeLs.hpp
@@ -103,7 +103,7 @@ int TapeLsStream::fillBuffer(XrdSsiPb::OStreamBuffer<Data> *streambuf) {
     tape_item->set_logical_library(tape.logicalLibraryName);
     tape_item->set_tapepool(tape.tapePoolName);
     tape_item->set_vo(tape.vo);
-    tape_item->set_encryption_key((bool)tape.encryptionKey ? tape.encryptionKey.value() : "-");
+    tape_item->set_encryption_key_name((bool)tape.encryptionKeyName ? tape.encryptionKeyName.value() : "-");
     tape_item->set_capacity(tape.capacityInBytes);
     tape_item->set_occupancy(tape.dataOnTapeInBytes);
     tape_item->set_last_fseq(tape.lastFSeq);
diff --git a/xroot_plugins/XrdSsiCtaRequestMessage.cpp b/xroot_plugins/XrdSsiCtaRequestMessage.cpp
index 0e194a60e3f032c1598c49a07dc06bb26dea6c0b..a6627fe0bb8bc7a98c3990b6204864d5d479568f 100644
--- a/xroot_plugins/XrdSsiCtaRequestMessage.cpp
+++ b/xroot_plugins/XrdSsiCtaRequestMessage.cpp
@@ -1361,17 +1361,17 @@ void RequestMessage::processTape_Ch(cta::xrd::Response &response)
 {
    using namespace cta::admin;
 
-   auto &vid            = getRequired(OptionString::VID);
-   auto  mediaType      = getOptional(OptionString::MEDIA_TYPE);
-   auto  vendor         = getOptional(OptionString::VENDOR);
-   auto  logicallibrary = getOptional(OptionString::LOGICAL_LIBRARY);
-   auto  tapepool       = getOptional(OptionString::TAPE_POOL);
-   auto  capacity       = getOptional(OptionUInt64::CAPACITY);
-   auto  comment        = getOptional(OptionString::COMMENT);
-   auto  encryptionkey  = getOptional(OptionString::ENCRYPTION_KEY);
-   auto  disabled       = getOptional(OptionBoolean::DISABLED);
-   auto  full           = getOptional(OptionBoolean::FULL);
-   auto  readOnly       = getOptional(OptionBoolean::READ_ONLY);
+   auto &vid               = getRequired(OptionString::VID);
+   auto  mediaType         = getOptional(OptionString::MEDIA_TYPE);
+   auto  vendor            = getOptional(OptionString::VENDOR);
+   auto  logicallibrary    = getOptional(OptionString::LOGICAL_LIBRARY);
+   auto  tapepool          = getOptional(OptionString::TAPE_POOL);
+   auto  capacity          = getOptional(OptionUInt64::CAPACITY);
+   auto  comment           = getOptional(OptionString::COMMENT);
+   auto  encryptionkeyName = getOptional(OptionString::ENCRYPTION_KEY_NAME);
+   auto  disabled          = getOptional(OptionBoolean::DISABLED);
+   auto  full              = getOptional(OptionBoolean::FULL);
+   auto  readOnly          = getOptional(OptionBoolean::READ_ONLY);
 
    if(mediaType) {
       m_catalogue.modifyTapeMediaType(m_cliIdentity, vid, mediaType.value());
@@ -1391,8 +1391,8 @@ void RequestMessage::processTape_Ch(cta::xrd::Response &response)
    if(comment) {
       m_catalogue.modifyTapeComment(m_cliIdentity, vid, comment.value());
    }
-   if(encryptionkey) {
-      m_catalogue.modifyTapeEncryptionKey(m_cliIdentity, vid, encryptionkey.value());
+   if(encryptionkeyName) {
+      m_catalogue.modifyTapeEncryptionKeyName(m_cliIdentity, vid, encryptionkeyName.value());
    }
    if(disabled) {
       m_catalogue.setTapeDisabled(m_cliIdentity, vid, disabled.value());
diff --git a/xrootd-ssi-protobuf-interface b/xrootd-ssi-protobuf-interface
index e40c45028c42a208cfd820fb8eec598314a35c23..38ca9bca9acc5cc31a08cbd1f1ecc45e78bf3401 160000
--- a/xrootd-ssi-protobuf-interface
+++ b/xrootd-ssi-protobuf-interface
@@ -1 +1 @@
-Subproject commit e40c45028c42a208cfd820fb8eec598314a35c23
+Subproject commit 38ca9bca9acc5cc31a08cbd1f1ecc45e78bf3401
diff --git a/common/dataStructures/Tape.hpp b/common/dataStructures/Tape.hpp
index bbd884b9bc1162126f8ea335c9fe9b74284047b0..fadecc15bcdcdf6deec1b67ab538ed211081351c 100644
--- a/common/dataStructures/Tape.hpp
+++ b/common/dataStructures/Tape.hpp
@@ -53,12 +53,12 @@ struct Tape {
   uint64_t dataOnTapeInBytes;
 
   /**
    * The optional identifier of the encrption key.
    *
    * This optional should either have a non-empty string value or no value at
    * all.  Empty strings are prohibited.
    */
-  optional<std::string> encryptionKey;
+  optional<std::string> encryptionKeyName;
 
   bool full;
   bool disabled;
@@ -53,12 +53,12 @@ struct Tape {
 
   /**
-   * The optional identifier of the encrption key.
+   * The optional name of the encryption key.
    *
    * This optional should either have a non-empty string value or no value at